#!/usr/bin/env lua 
-- See the "conversions" table below to define 
-- which variables you want to convert, and how.
--

local BASE_Fs = 48000
local BASE_Ts = 1/BASE_Fs
local BASE_Ts_ms = 1000/BASE_Fs

local log10_e = math.log10( math.exp(1) )
local twenty_log10_e = 20 * log10_e

local function fc2coef_1( fc, Ts )
-- calculate the coefficient needed in a first order "time constant style"
-- filter (i.e. without a zero at Nyquist) in order to make the -3dB
-- frequency equal to fc for a sample period of Ts
    local w = 2 * math.pi * fc * Ts
    local c = math.cos( w )
    return 2 - c - math.sqrt( (c - 4)*c + 3  )
end

local function tc2coef_1( tc, Ts )
-- calculate the coefficient needed to implement the RC-equivalent
-- time-constant (under impulse-invariant transform) in a first order
-- filter for a sample period of Ts.  Note that tc must be in the
-- same units as Ts.
-- The exact equation is a = 1 - exp( -(Ts/tc) ).  The expression below
-- is an approximation which is very good for tc of more than a few samples.
   return Ts / tc
end

--+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
--
-- specific variables to convert and the associated conversion 
-- functions here. 
--
local conversions = {
    APS_loagc_mix = function(x) return x + 1.5 end,
    APS_mlagc_mix = function(x) return x - 3 end,
    APS_mhagc_mix = function(x) return x - 3 end,
    APS_hiagc_mix = function(x) return x - 2 end,
    APS_lim_drive = function(x) return x + 1.5 end, 
    APS_mllim_thresh = function(x) return x - 2.0 end,
    APS_lolim_thresh = function(x) return x -1.0 end,
    APS_clip_drive = function(x) return x - 1.5 end,
    APS_bass_enh_thresh = function(x) return 15 end,
    APS_sllim_mix = function(x) return x + 1 end,
    APS_sllim_hd_mix = function(x) return x + 1 end,
    APS_sllim_ratio = function(x) return 0.8 end,
    APS_shlim_ratio = function(x) return 0.8 end,
    APS_lolim_ratio = function(x) return 0.9 end, 
    APS_mhlim_ratio = function(x) return 0.85 end,
    APS_hilim_ratio = function(x) return 0.85 end,
    APS_mllim_ratio = function(x) return 0.9 end,
    APS_shlim_att_cal = function(x) return 41.30 end,
    APS_hilim_att_cal = function(x) return 83.07109 end,
    APS_mhlim_att_cal = function(x) return 104.827117 end,
    APS_mllim_att_cal = function(x) return 104.827117 end,
    APS_sllim_att_cal = function(x) return 3236.971191 end, 
    APS_lolim_att_cal = function(x) return 345.7209777 end,
    APS_lim_incomp = function(x) return 0.0 end, 

}
--+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

local function print_line( name, val )
    if type( val ) == "number" then
        assert( io.write( string.format("\t%s = %g,\n", name, val) ) )
    else
        assert( io.write( string.format("\t%s = %q,\n", name, val) ) )
    end
end

local function convert( name, val )
    local f = conversions[ name ]
    if f then
        print_line( name, f( val ) )
    else
        print_line( name, val )
    end  
end

local function convertPreset( fname )
   -- the preset file calls "Preset"
   function Preset( t ) 
      table.foreach( t, convert )
   end
   local f = loadfile( fname )
   if not f then return false end
   -- Now actually execute the preset file
   io.write( "Preset {\n" )
   f()
   io.write( "}\n" );
   return true
end

assert( convertPreset( arg[1] ) )
